<?php
/**
 * This example creates a copy of an image creative. To determine which
 * image creatives exist, run GetImageCreatives.php.
 *
 * PHP version 5
 *
 * Copyright 2016, Google Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * @package    GoogleApiAdsDfp
 * @subpackage v201605
 * @category   WebServices
 * @copyright  2016, Google Inc. All Rights Reserved.
 * @license    http://www.apache.org/licenses/LICENSE-2.0 Apache License,
 *             Version 2.0
 */
error_reporting(E_STRICT | E_ALL);

// You can set the include path to src directory or reference
// DfpUser.php directly via require_once.
// $path = '/path/to/dfp_api_php_lib/src';
$path = dirname(__FILE__) . '/../../../../src';
set_include_path(get_include_path() . PATH_SEPARATOR . $path);

require_once 'Google/Api/Ads/Dfp/Lib/DfpUser.php';
require_once 'Google/Api/Ads/Dfp/Util/v201605/StatementBuilder.php';
require_once dirname(__FILE__) . '/../../../Common/ExampleUtils.php';

// Set the ID of the image creative to copy.
$creativeId = 'INSERT_CREATIVE_ID_HERE';

try {
  // Get DfpUser from credentials in "../auth.ini"
  // relative to the DfpUser.php file's directory.
  $user = new DfpUser();

  // Log SOAP XML request and response.
  $user->LogDefaults();

  // Get the CreativeService.
  $creativeService = $user->GetService('CreativeService', 'v201605');

  // Create a statement to get the image creative.
  $statementBuilder = new StatementBuilder();
  $statementBuilder->where('id = :id')
      ->orderBy("id ASC")
      ->limit(StatementBuilder::SUGGESTED_PAGE_LIMIT)
      ->withBindVariableValue('id', $creativeId);

  // Get the creative.
  $imageCreative = $creativeService->getCreativesByStatement(
      $statementBuilder->toStatement())->results[0];

  // Fetch the image asset.
  $assetToCopy = $imageCreative->primaryImageAsset;

  $aspectRatioSize = $imageCreative->size;
  $aspectRatioSize->isAspectRatio = true;

  $newImageCreative = new AspectRatioImageCreative();
  $newImageCreative->name = 'Copy of original image creative';
  $newImageCreative->size = $aspectRatioSize;
  $newImageCreative->advertiserId = $imageCreative->advertiserId;
  $newImageCreative->imageAssets = array($assetToCopy);
  $newImageCreative->destinationUrl = $imageCreative->destinationUrl;

  // Create the new image creative on the server.
  $imageCreatives = $creativeService->createCreatives(array($newImageCreative));

  // Display results.
  foreach ($imageCreatives as $creative) {
    printf(
        "An image creative with ID %d, name '%s', and size '%sx%s' was created "
            . "and can be previewed at: '%s'\n",
        $creative->id,
        $creative->name,
        $creative->size->width,
        $creative->size->height,
        $creative->previewUrl
    );
  }
} catch (OAuth2Exception $e) {
  ExampleUtils::CheckForOAuth2Errors($e);
} catch (ValidationException $e) {
  ExampleUtils::CheckForOAuth2Errors($e);
} catch (Exception $e) {
  printf("%s\n", $e->getMessage());
}

